@@ -1,12 +1,10 @@
 //! Everything related to `libavcodec`.
-mod avpicture;
 mod codec;
 mod codec_id;
 mod codec_par;
 mod packet;
 mod parser;
 
-pub use avpicture::*;
 pub use codec::*;
 pub use codec_id::*;
 pub use codec_par::*;
